package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcQinglangZhuanxiangMapper;
import com.ruoyi.zongzhi.domain.TcQinglangZhuanxiang;
import com.ruoyi.zongzhi.service.ITcQinglangZhuanxiangService;

/**
 * 清朗专项Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@Service
public class TcQinglangZhuanxiangServiceImpl implements ITcQinglangZhuanxiangService 
{
    @Autowired
    private TcQinglangZhuanxiangMapper tcQinglangZhuanxiangMapper;

    /**
     * 查询清朗专项
     * 
     * @param id 清朗专项主键
     * @return 清朗专项
     */
    @Override
    public TcQinglangZhuanxiang selectTcQinglangZhuanxiangById(Long id)
    {
        return tcQinglangZhuanxiangMapper.selectTcQinglangZhuanxiangById(id);
    }

    /**
     * 查询清朗专项列表
     * 
     * @param tcQinglangZhuanxiang 清朗专项
     * @return 清朗专项
     */
    @Override
    public List<TcQinglangZhuanxiang> selectTcQinglangZhuanxiangList(TcQinglangZhuanxiang tcQinglangZhuanxiang)
    {
        return tcQinglangZhuanxiangMapper.selectTcQinglangZhuanxiangList(tcQinglangZhuanxiang);
    }

    /**
     * 新增清朗专项
     * 
     * @param tcQinglangZhuanxiang 清朗专项
     * @return 结果
     */
    @Override
    public int insertTcQinglangZhuanxiang(TcQinglangZhuanxiang tcQinglangZhuanxiang)
    {
        tcQinglangZhuanxiang.setCreateTime(DateUtils.getNowDate());
        return tcQinglangZhuanxiangMapper.insertTcQinglangZhuanxiang(tcQinglangZhuanxiang);
    }

    /**
     * 修改清朗专项
     * 
     * @param tcQinglangZhuanxiang 清朗专项
     * @return 结果
     */
    @Override
    public int updateTcQinglangZhuanxiang(TcQinglangZhuanxiang tcQinglangZhuanxiang)
    {
        tcQinglangZhuanxiang.setUpdateTime(DateUtils.getNowDate());
        return tcQinglangZhuanxiangMapper.updateTcQinglangZhuanxiang(tcQinglangZhuanxiang);
    }

    /**
     * 批量删除清朗专项
     * 
     * @param ids 需要删除的清朗专项主键
     * @return 结果
     */
    @Override
    public int deleteTcQinglangZhuanxiangByIds(Long[] ids)
    {
        return tcQinglangZhuanxiangMapper.deleteTcQinglangZhuanxiangByIds(ids);
    }

    /**
     * 删除清朗专项信息
     * 
     * @param id 清朗专项主键
     * @return 结果
     */
    @Override
    public int deleteTcQinglangZhuanxiangById(Long id)
    {
        return tcQinglangZhuanxiangMapper.deleteTcQinglangZhuanxiangById(id);
    }
}
